/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __SCREEN_CONNECTOR_WATCHER_EVAS_H__
#define __SCREEN_CONNECTOR_WATCHER_EVAS_H__

#include <Evas.h>
#include <tizen.h>
#include <tizen_type.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @file screen_connector_watcher_evas.h
 * @brief  This file declares API of libscreen_connector library
 * @since_tizen 3.0
 */

/**
 * @addtogroup CAPI_SCREEN_CONNECTOR_WATCHER_EVAS_MODULE
 * @{
 */

typedef enum {
	VISIBILITY_TYPE_UNOBSCURED,
	VISIBILITY_TYPE_PARTIALLY_OBSCURED,
	VISIBILITY_TYPE_FULLY_OBSCURED,
} visibility_type;

typedef void (*screen_connector_watcher_evas_added_cb)(const char *appid, Evas_Object *image, void *data);
typedef void (*screen_connector_watcher_evas_removed_cb)(const char *appid, Evas_Object *image, void *data);
typedef void (*screen_connector_watcher_evas_updated_cb)(const char *appid, Evas_Object *image, void *data);

typedef struct _screen_connector_watcher_evas_ops {
	screen_connector_watcher_evas_added_cb added;
	screen_connector_watcher_evas_removed_cb removed;
	screen_connector_watcher_evas_updated_cb updated;
} screen_connector_watcher_evas_ops;

typedef struct _screen_connector_watcher_evas_h *screen_connector_watcher_evas_h;

int screen_connector_watcher_evas_init(Evas_Object *win);
int screen_connector_watcher_evas_fini(void);
screen_connector_watcher_evas_h screen_connector_watcher_evas_add(screen_connector_watcher_evas_ops *ops, char *id, void *data);
int screen_connector_watcher_evas_remove(screen_connector_watcher_evas_h handle);
int screen_connector_watcher_evas_update(const char *appid);
int screen_connector_watcher_evas_start_visibility_notify(void);
int screen_connector_watcher_evas_stop_visibility_notify(void);
int screen_connector_watcher_evas_freeze_visibility(Evas_Object *obj, visibility_type type);
int screen_connector_watcher_evas_thaw_visibility(Evas_Object *obj);
int screen_connector_watcher_evas_send_mouse_up(Evas_Object *obj);
int screen_connector_watcher_evas_send_touch_cancel(Evas_Object *obj);
int screen_connector_watcher_evas_get_pid(Evas_Object *obj, int *pid);
int screen_connector_watcher_evas_add_by_rid(screen_connector_watcher_evas_ops *ops, int res_id, void *data);
int screen_connector_watcher_evas_get_rid(Evas_Object *obj, int *resource_id);

/**
 * @}
 */

#ifdef __cplusplus
}
#endif

#endif /* __SCREEN_CONNECTOR_WATCHER_EVAS_H__ */
